###############
### Setup R ###
###############

### Clear terminal
cat("\014")

### Clear space
rm(list = ls())

### Load packages
library(readstata13)
library(sandwich)
library(randomForest)
library(lmtest)
library(MASS)
library(sciplot)
library(lme4)
library(DAAG)
library(ordinal)
library(sciplot)
library(foreach)
library(plyr)
library(doMC)
library(Hmisc)
library(effects)
library(WDI)
library(countrycode)
library(DataCombine)
library(reshape)
library(doBy)
library(lmtest)

set.seed(06272016)

##################
### Setup Data ###
##################

### Set working directory
setwd("~/Dropbox/charles/replication_reply/volatility")

dat <- read.dta13("bjps_powell_tucker_dataset2.dta")
colnames(dat)

###########################
### Make coefficient plot #
###########################

par(
  oma = c(0,0,0,0),
  mar = c(5,2,4,2)
)

plot(NULL,
     xlim = c(-20, 10),
     ylim = c(1, 5),
     axes = F, xlab = NA, ylab = NA)
abline(v = 0, lty = 3, lwd=2, col = "#aaaaaa")

axis(side = 1)
mtext(side = 1, "Change in Replacement Volatility", line = 2.5) 
text(-8.7216, 4, "GDP Change from 1989 \n (Uncorrected Data)", xpd = T, cex = .8, pos = 3, offset=0.7)
lines(c(-3.501844, -13.94136), c(4, 4), lwd = 12, col="#333333")
points(-8.7216, 4, pch = 19, cex = 3, col="white")
points(-8.7216, 4, pch = 19, cex = 2, col="black")

text(-4.693997, 2, "GDP Change from 1989 \n (Corrected Data)", xpd = T, cex = .8, pos = 3, offset=0.7)
lines(c(-15.4762, 6.088206), c(2, 2), lwd = 12, col="#333333")
points(-4.693997, 2, pch = 19, cex = 3, col="white")
points(-4.693997, 2, pch = 19, cex = 2, col="black")

###################################
### Make Variable Importance Plot #
###################################

set.seed(07012016)
rf.fit <- randomForest(dat$TypeAVol ~ dat$GDPChange1989_corrected + dat$GDPChangeE1E2 + dat$Enp1 + dat$lg_weighted_mag + dat$presys + dat$mixsys + dat$pr + dat$EthFrac + dat$Time + dat$Time2 + dat$mis_weighted_mag, importance=TRUE)
par(bty = 'n') 
fin.labels <- c(rev(c("Log Weighted District Magnitude", 
                      "GDP Change Between Elections", 
                      "Years Since Collapse of Communism", 
                      "Years Since Collapse Squared",
                      "Ethnic Fractionalization", 
                      "GDP Change from 1989 (Corrected Data)", 
                      "Presidential System",
                      "Semi-Presidential System", 
                      "Proportional Representation", 
                      "Effective Number of Electoral Parties", 
                      "District Magnitude - Missing")))
varImpPlot(rf.fit, type=1, bty='n', lcolor="gray", labels=fin.labels,  col="grey20", pch=19, main="")
